# Generated by Django 3.0.5 on 2020-04-22 00:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("data", "0002_auto_20200422_0028")]

    operations = [
        migrations.RemoveField(model_name="membershiplink", name="membership"),
        migrations.DeleteModel(name="MembershipContactDetail"),
        migrations.DeleteModel(name="MembershipLink"),
    ]
