# Generated by Django 3.0.5 on 2020-08-21 10:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0016_auto_20200811_1016"),
    ]

    operations = [
        migrations.RemoveField(model_name="person", name="summary",),
    ]
