# Generated by Django 3.0.5 on 2020-09-14 10:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0019_remove_billabstract_date"),
    ]

    operations = [
        migrations.RemoveField(model_name="billidentifier", name="note",),
        migrations.RemoveField(model_name="billidentifier", name="scheme",),
    ]
