# Generated by Django 3.0.5 on 2020-09-14 11:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0023_remove_personcontactdetail_label"),
    ]

    operations = [
        migrations.RemoveField(model_name="post", name="end_date",),
        migrations.RemoveField(model_name="post", name="start_date",),
    ]
