# Generated by Django 3.0.5 on 2020-09-14 11:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0022_auto_20200914_1054"),
    ]

    operations = [
        migrations.RemoveField(model_name="personcontactdetail", name="label",),
    ]
