# Generated by Django 3.0.5 on 2020-08-11 10:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("data", "0015_auto_20200811_1009"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="voteevent", options={"ordering": ["start_date", "order"]},
        ),
        migrations.RemoveField(model_name="voteevent", name="end_date",),
        migrations.AddField(
            model_name="voteevent",
            name="order",
            field=models.PositiveIntegerField(default=0),
        ),
    ]
